@@ -222,6 +222,15 @@ class CHDKCameraDevice(DevicePlugin):
             "--zoom-level", "-z", dest="zoom_level", type=int, metavar="<int>",
             help="Zoom level")
 
+    @classmethod
+    def match(cls, device):
+        # TODO: This matches all PTP devices, we will have to ensure that
+        #       it is also a CHDK compatible device.
+        cfg = device.get_active_configuration()[(0, 0)]
+        matches = (hex(cfg.bInterfaceClass) == "0x6"
+                   and hex(device.bInterfaceSubClass) == "0x1")
+        return matches
+
     def __init__(self, config, device):
         """ Set connection information and try to obtain orientation.
 
